@@ -5,7 +5,7 @@ Requires cx_Oracle: http://www.python.net/crew/atuining/cx_Oracle/
 
 import os, sys
 from django.db.backends import BaseDatabaseWrapper, BaseDatabaseValidation, util
-
+from django.db.backends.signals import connection_created
 # Makes it explicit where the default oracle versions fo these components are used
 from django.db.backends.oracle.base import OracleParam
 from django.db.backends.oracle.base import DatabaseFeatures as OracleDatabaseFeatures
@@ -121,6 +121,9 @@ logger = get_logger(DATABASE_EXTRAS)
 class DatabaseFeatures(OracleDatabaseFeatures):
     """ Add extra options from default Oracle ones
         Plus switch off save points and id return
+        See http://groups.google.com/group/django-developers/browse_thread/thread/bca33ecf27ff5d63
+        Savepoints could be turned on but are not needed
+        and since they may impact performance they are turned off here 
     """
     uses_savepoints = False
     can_return_id_from_insert = False
@@ -290,11 +293,12 @@ class DatabaseWrapper(BaseDatabaseWrapper):
                 # Django docs specify cx_Oracle version 4.3.1 or higher, but
                 # stmtcachesize is available only in 4.3.2 and up.
                 pass
+            connection_created.send(sender=self.__class__)
         else:
             if logger:
                 logger.critical('Pool couldnt be created')
             else:
-                raise u'Pool couldnt be created'
+                raise 'Pool couldnt be created'
             
         if not cursor:
             cursor = FormatStylePlaceholderCursor(self.connection)
@@ -310,6 +314,10 @@ class DatabaseWrapper(BaseDatabaseWrapper):
             self.pool.release(self.connection)
             self.connection = None
 
+    def _savepoint_commit(self, sid):
+        """ Oracle doesn't support savepoint commits.  Ignore them. """
+        pass
+
 class FormatStylePlaceholderCursor(OracleFormatStylePlaceholderCursor):
     """ Added just to allow use of % for like queries without params
         and use of logger if present.
@@ -336,7 +344,7 @@ class FormatStylePlaceholderCursor(OracleFormatStylePlaceholderCursor):
                 if logger:
                     logger.critical(err)
                 else:
-                    raise unicode(err)
+                    raise str(err)
                 
     def execute(self, query, params=[]):
         if params is None:
@@ -356,7 +364,7 @@ class FormatStylePlaceholderCursor(OracleFormatStylePlaceholderCursor):
             if logger:
                 logger.critical(err)
             else:
-                raise unicode(err)
+                raise err
 
     def executemany(self, query, params=[]):
         try:
@@ -377,4 +385,4 @@ class FormatStylePlaceholderCursor(OracleFormatStylePlaceholderCursor):
             if logger:
                 logger.critical('%s due to query:%s' % (e, query))                
             else:
-                raise unicode(e)
+                raise str(e)
